@@ -11,9 +11,12 @@ from .sym import sym
 @sym.command("exec", short_help="Execute a command")
 @resource_argument
 @click.argument("command", nargs=-1)
-@loses_interactivity
 @click.make_pass_decorator(GlobalOptions)
 @require_login
+@loses_interactivity
 def sym_exec(options: GlobalOptions, resource: str, command: Tuple[str, ...]) -> None:
     """Use approved creds for RESOURCE to execute COMMAND."""
-    options.create_saml_client(resource).exec(*command)
+    from ..saml_clients.saml_client_factory import SAMLClientFactory
+
+    saml_client = SAMLClientFactory.create_saml_client(resource, options)
+    saml_client.exec(*command)
