@@ -4,7 +4,7 @@ import subprocess
 import sys
 from datetime import timedelta
 from pathlib import Path
-from signal import SIGPIPE, signal
+from signal import SIGINT, SIGPIPE, signal
 from subprocess import CalledProcessError
 from textwrap import dedent
 from typing import List, Sequence, Tuple
@@ -292,8 +292,8 @@ def ensure_ssh_key(
     ensure_public_key_on_instance(client, instance, port, args=args)
 
 
-def _handler_factory(instance):
-    def handler(signum, frame):
+def _set_handlers(instance):
+    def pipe_handler(signum, frame):
         devnull = os.open(os.devnull, os.O_WRONLY)
         os.dup2(devnull, sys.stdout.fileno())
         # Set error state on session end.
@@ -303,13 +303,19 @@ def _handler_factory(instance):
         # loops with Ansible due to missing SSH public keys.
         Config.touch_instance(instance, error=True)
 
-    return handler
+    def int_handler(signum, frame):
+        # Ignore Control-Cs.
+        # Let them be handled by the remote shell
+        pass
+
+    signal(SIGPIPE, pipe_handler)
+    signal(SIGINT, int_handler)
 
 
 def start_tunnel(client, instance: str, port: int):
     client.dprint("execing aws ssm")
     SymGroup.reset_tees()
-    signal(SIGPIPE, _handler_factory(instance))
+    _set_handlers(instance)
 
     with ssm_ssh_session(client, instance, port) as command:
         client.exec(*command, suppress_=True)
@@ -318,7 +324,7 @@ def start_tunnel(client, instance: str, port: int):
 def start_interactive_command(client, instance: str, command: Sequence[str]):
     client.dprint("execing aws ssm interactive command")
     SymGroup.reset_tees()
-    signal(SIGPIPE, _handler_factory(instance))
+    _set_handlers(instance)
 
     with ssm_interactive_command(client, instance, get_ssh_user(), command) as command:
         client.exec(*command, suppress_=True)
