@@ -3,11 +3,10 @@ from botocore.exceptions import ClientError
 from botocore.paginate import Paginator
 
 from sym.cli.errors import BotoError
-from sym.cli.helpers.boto import boto_client, host_to_instance, send_ssh_key
+from sym.cli.helpers.boto import send_ssh_key
 from sym.cli.helpers.config import SymConfigFile
+from sym.cli.helpers.ec2.client import Ec2Client
 from sym.cli.helpers.ssh import SSHKeyPath
-from sym.cli.saml_clients.aws_profile import AwsProfile
-from sym.cli.tests.saml_clients.conftest import TestContextFixture
 
 
 def test_error_handling_unauthorized(monkeypatch, boto_stub, click_context, saml_client):
@@ -28,7 +27,7 @@ def test_error_handling_unauthorized(monkeypatch, boto_stub, click_context, saml
         with pytest.raises(
             BotoError, match="Does your user role have permission to DescribeInstances?"
         ):
-            host_to_instance(saml_client, "localhost")
+            Ec2Client(saml_client).load_instance_by_alias("localhost")
 
 
 def test_error_handling_expired(monkeypatch, boto_stub, click_context, saml_client):
@@ -47,7 +46,7 @@ def test_error_handling_expired(monkeypatch, boto_stub, click_context, saml_clie
 
     with click_context:
         with pytest.raises(BotoError, match="Your AWS credentials have expired."):
-            host_to_instance(saml_client, "localhost")
+            Ec2Client(saml_client).load_instance_by_alias("localhost")
 
 
 def test_wait_for_invocation(saml_client, boto_stub, monkeypatch, click_context) -> None:
